
#include <amxmodx>
#include <fakemeta>

#define PLUGIN	"Tetris ASCII newmenus.inc"
#define AUTHOR	"Albernaz o Carniceiro Demoniaco"
#define VERSION	"1.1"

const MAX_PLAYERS = 33

enum GAME_STATE
{
	START,
	IN_GAME,
	GAME_OVER
}

enum POSITION
{
	ROW,
	COL
}

enum PIECE_NAME
{
	I,
	J,
	L,
	O,
	S,
	T,
	Z
}

enum TABLE_DIM
{
	ROWS,
	COLS
}

enum CELL_COLOR
{
	INACTIVE,
	ACTIVE
}

enum SOUND
{
	SELECTION,
	LINE,
	FALL,
	GAMEOVER
}

new Sounds[SOUND][] = { "tetris/selection.wav", "tetris/line.wav" , "tetris/fall.wav", "tetris/gameover.wav"}

enum MUSIC
{
	MUSIC1,
	MUSIC2,
	MUSIC3
}

new Musics[MUSIC][] = { "tetris/music1.mp3","tetris/music2.mp3","tetris/music3.mp3"}

enum DIFFICULTY_LEVEL
{
	CHILD,
	MAN,
	LUMBERJACK
}

const difficultyLevelLabelMaxLen = 12
new difficultyLevelLabel[DIFFICULTY_LEVEL][difficultyLevelLabelMaxLen] = {"Child","Man","LumberJack"}
new Float:difficultyLevelsTaskDelay[DIFFICULTY_LEVEL] = {_:0.3,_:0.2,_:0.1}
new DIFFICULTY_LEVEL:playersDifficultyLevel[MAX_PLAYERS];

new cellChar[] = {"O"}
new cellCharColors[CELL_COLOR][] = {"\d","\r"}

const PieceSquareMaxWidth = 4;
new const PiecesSquareWidth[PIECE_NAME] = {4,3,3,2,3,3,3}
new bool:PiecesData[PIECE_NAME][PieceSquareMaxWidth][PieceSquareMaxWidth];

const TableRows = 14
const TableCols = 10
new const bool:PlayersTables[MAX_PLAYERS][TableRows][TableCols]

new GAME_STATE:PlayersGameState[MAX_PLAYERS]

new GameStatesMenusIDs[GAME_STATE]

new bool:PlayersCurrentPieceData[MAX_PLAYERS][PieceSquareMaxWidth][PieceSquareMaxWidth]
new PIECE_NAME:PlayersCurrentPieceName[MAX_PLAYERS]
new PlayersCurrentPiecePosition[MAX_PLAYERS][POSITION]

new bool:PlayersNextPieceData[MAX_PLAYERS][PieceSquareMaxWidth][PieceSquareMaxWidth]
new PIECE_NAME:PlayersNextPieceName[MAX_PLAYERS]
new PlayersNextPiecePosition[MAX_PLAYERS][POSITION]

new bool:PlayersTableCellActive[MAX_PLAYERS]

new PlayersTaskID[MAX_PLAYERS]
new Float:PlayersTaskDelay[MAX_PLAYERS]
new PlayersMenuInGame[MAX_PLAYERS]

new MenuTextTitle[] = "Tetris ASCII^n"
new MenuTextTitleGameOver[] = "Tetris ASCII^n^nGAME OVER^n"

new PlayersButtons = IN_MOVELEFT | IN_MOVERIGHT | IN_FORWARD | IN_BACK;

new PlayersPreviousPressedButton[MAX_PLAYERS];
new PlayersIsPlaying[MAX_PLAYERS];

new Float:PlayersPreviousMaxspeed[MAX_PLAYERS]

public plugin_precache()
{
	for(new SOUND:i=SOUND:0;i<SOUND;i++)
		precache_sound(Sounds[i])
	
	for(new MUSIC:i=MUSIC:0;i<MUSIC;i++)
		precache_sound(Musics[i])
}

public plugin_cfg()
{
	PiecesData[I][0] = bool:{ false, true, false , false }
	PiecesData[I][1] = bool:{ false, true, false , false }
	PiecesData[I][2] = bool:{ false, true, false , false }
	PiecesData[I][3] = bool:{ false, true, false , false }
	
	PiecesData[J][0] = bool:{ true, false, false , false }
	PiecesData[J][1] = bool:{ true, true, true , false }
	
	PiecesData[L][0] = bool:{ false, false, true , false }
	PiecesData[L][1] = bool:{ true, true, true , false }
	
	PiecesData[O][0] = bool:{ true, true, false , false }
	PiecesData[O][1] = bool:{ true, true, false , false }
	
	PiecesData[S][0] = bool:{ false, true, true , false }
	PiecesData[S][1] = bool:{ true, true, false , false }
	
	PiecesData[T][0] = bool:{ false, true, false, false }
	PiecesData[T][1] = bool:{ true, true, true , false }
	
	PiecesData[Z][0] = bool:{ true, true, false , false }
	PiecesData[Z][1] = bool:{ false, true, true , false }
	
	GameStatesMenusIDs[START] 		= funcidx("menuTetrisStart");
	GameStatesMenusIDs[IN_GAME] 	= funcidx("menuTetrisInGamePre");
	GameStatesMenusIDs[GAME_OVER] 	= funcidx("menuTetrisGameOver");
}

public plugin_init()
{
	register_plugin(PLUGIN, VERSION, AUTHOR)
	register_clcmd("tetris","menuTetris");
	register_clcmd("say tetris","menuTetris");
	register_cvar("tetrisASCIIVersion",VERSION,FCVAR_SERVER);
	
	register_forward(FM_PlayerPostThink,"playerPostThink");
}

public playerPostThink(id)
{
	if(PlayersIsPlaying[id])
	{
		new Float:maxspeed 
		
		pev(id,pev_maxspeed,maxspeed);
			
		if((maxspeed != 1.0) && (maxspeed != PlayersPreviousMaxspeed[id]))
		{
			PlayersPreviousMaxspeed[id] = maxspeed;
		}
		
		set_pev(id,pev_maxspeed,1.0)
		
		new button = pev(id, pev_button)
		
		new myButton = button & PlayersButtons;
		
		if(myButton)
		{	
			new buttonUnique = myButton & ~PlayersPreviousPressedButton[id]

			if(buttonUnique)
			{
				new bool:pieceData[PieceSquareMaxWidth][PieceSquareMaxWidth]
				new piecePosition[POSITION]
				new PIECE_NAME:pieceName
				
				clonePiece(PlayersCurrentPieceData[id],pieceData,PlayersCurrentPiecePosition[id],piecePosition,PlayersCurrentPieceName[id]);
				
				pieceName = PlayersCurrentPieceName[id]
				
				switch(buttonUnique)
				{
					case IN_MOVELEFT:
					{
						piecePosition[COL]--;
					}
					case IN_MOVERIGHT:
					{
						piecePosition[COL]++;
					}
					case IN_FORWARD:
					{
						rotatePiece(pieceData,pieceName)
					}
					case IN_BACK:
					{
						piecePosition[ROW]++;	
					}
				}
				
				if(isValidPieceInTable(id,pieceData,piecePosition,pieceName))
				{
					PlayersCurrentPiecePosition[id] = piecePosition;
					PlayersCurrentPieceData[id] = pieceData;
				}
				
				menuTetrisInGame(id)
			}
		}
		
		PlayersPreviousPressedButton[id] = button;
	}
}

public client_connect(id)
{
	PlayersGameState[id] = START
	playersDifficultyLevel[id] = DIFFICULTY_LEVEL:0;
}

public client_disconnect(id)
{
	if(PlayersIsPlaying[id])
		playerQuitingGame(id);
}

newTask(id,&taskID,&Float:taskDelay)
{
	taskDelay = difficultyLevelsTaskDelay[playersDifficultyLevel[id]]
	
	do
	{
		taskID = random(999999);
	}
	while(task_exists(taskID));
}

rotatePiece(bool:piece[PieceSquareMaxWidth][PieceSquareMaxWidth],PIECE_NAME:pieceName)
{
	new pieceSquareWidth = PiecesSquareWidth[pieceName]
	new biggerIndex = pieceSquareWidth - 1;
	
	new bool:newPiece[PieceSquareMaxWidth][PieceSquareMaxWidth]
	
	for(new i=0;i<pieceSquareWidth;i++)
		for(new j=0;j<pieceSquareWidth;j++)
			newPiece[i][j] = piece[biggerIndex - j][i]
		
	piece = newPiece;
}

clonePiece(bool:piece1Data[PieceSquareMaxWidth][PieceSquareMaxWidth],bool:piece2Data[PieceSquareMaxWidth][PieceSquareMaxWidth],piece1Position[POSITION],piece2Position[POSITION],PIECE_NAME:pieceName)
{
	new pieceSquareWidth = PiecesSquareWidth[pieceName]
	
	for(new i = 0 ; i< pieceSquareWidth ; i++)
		for(new j = 0 ; j< pieceSquareWidth ; j++)
			piece2Data[i][j] = piece1Data[i][j];
		
	for(new POSITION:pos = ROW; pos < POSITION;pos++)
		piece2Position[pos] = piece1Position[pos];
}

getRandomPiece(bool:pieceData[PieceSquareMaxWidth][PieceSquareMaxWidth],piecePosition[POSITION],&PIECE_NAME:pieceName)
{
	pieceName = PIECE_NAME:random(_:PIECE_NAME);
	clonePiece(PiecesData[pieceName],pieceData,piecePosition,piecePosition,pieceName);
	
	initPiecePosition(piecePosition,pieceName);
}

initPiecePosition(piecePosition[POSITION],PIECE_NAME:pieceName)
{
	new pieceSquareWidth = PiecesSquareWidth[pieceName];
	
	piecePosition[ROW] = -1
	piecePosition[COL] = (TableCols / 2 + TableCols % 2) - (pieceSquareWidth / 2)
}

initPlayerGame(id)
{
	PlayersGameState[id] = IN_GAME;
	
	new bool:table[TableRows][TableCols]
	PlayersTables[id] = table;
	
	getRandomPiece(PlayersCurrentPieceData[id],PlayersCurrentPiecePosition[id],PlayersCurrentPieceName[id])
	getRandomPiece(PlayersNextPieceData[id],PlayersNextPiecePosition[id],PlayersNextPieceName[id])
	
	new params[1]
	params[0] = id
	
	newTask(id,PlayersTaskID[id],PlayersTaskDelay[id])
	
	playerEnteringGame(id,true);
}

playerEnteringGame(id,bool:starting = false)
{
	pev(id,pev_maxspeed,PlayersPreviousMaxspeed[id])
	
	new Float:delay = PlayersTaskDelay[id]
	
	if(!starting)
		delay /= 2.0
	
	new params[1]
	params[0] = id; 
	set_task(delay,"movePieceDownTask",PlayersTaskID[id],params,1,"a",1) 
	
	client_cmd(id,"mp3 loop sound/%s",Musics[MUSIC:random(_:MUSIC)] );
	PlayersIsPlaying[id] = true;
}
playerQuitingGame(id)
{	
	PlayersIsPlaying[id] = false;
	
	set_pev(id,pev_maxspeed,PlayersPreviousMaxspeed[id])
	
	new taskID = PlayersTaskID[id]
	
	if(task_exists(taskID))
		remove_task(taskID);
	
	client_cmd(id,"mp3 stop")
}

public menuTetris(id)
{
	callfunc_begin_i(GameStatesMenusIDs[PlayersGameState[id]])
	callfunc_push_int(id);
	callfunc_end();
	
	return PLUGIN_HANDLED;
}

public menuTetrisStart(id)
{
	new menu = menu_create("","handleMenuTetrisStart");
	
	menu_setprop(menu,MPROP_TITLE,MenuTextTitle);	
	menu_setprop(menu,MPROP_EXITNAME,"exit");
	
	menu_additem(menu,"Start Game","1");
	
	new difficultyLevelFormat[] = "Difficulty: ^"\r%s\w^"";
	
	const difficultyLevelLen = sizeof difficultyLevelFormat + difficultyLevelLabelMaxLen + 1;
	new difficultyLevel[difficultyLevelLen]
	
	format(difficultyLevel,difficultyLevelLen-1,difficultyLevelFormat,difficultyLevelLabel[playersDifficultyLevel[id]])
	
	menu_additem(menu,difficultyLevel,"2");
	
	menu_display(id,menu,0);
}

public handleMenuTetrisStart(id,menu,item)
{
	if(item >= 0) 
	{
		new access, callback; 
		
		new actionString[2];		
		menu_item_getinfo(menu,item,access, actionString,1,_,_, callback);		
		new action = str_to_num(actionString);	
		
		switch(action)
		{
			case 1:
			{
				initPlayerGame(id)				
				menuTetrisInGame(id);
			}
			case 2:
			{
				if(++playersDifficultyLevel[id] == DIFFICULTY_LEVEL)
					playersDifficultyLevel[id] = DIFFICULTY_LEVEL:0
			
				client_cmd(id,"spk %s",Sounds[SELECTION]);
			
				menuTetrisStart(id);
			}
		}
	}
	
	menu_destroy(menu);
	
	return PLUGIN_HANDLED;
}	

canMovePieceDown(id)
{	
	new bool:pieceData[PieceSquareMaxWidth][PieceSquareMaxWidth]
	new piecePosition[POSITION]
	new PIECE_NAME:pieceName
	
	clonePiece(PlayersCurrentPieceData[id],pieceData,PlayersCurrentPiecePosition[id],piecePosition,PlayersCurrentPieceName[id]);
	
	pieceName = PlayersCurrentPieceName[id]
	
	piecePosition[ROW]++;
	
	return isValidPieceInTable(id,pieceData,piecePosition,pieceName)
}
isValidPieceInTable(id,bool:pieceData[PieceSquareMaxWidth][PieceSquareMaxWidth],piecePosition[POSITION],PIECE_NAME:pieceName)
{	
	new pieceSquareWidth = PiecesSquareWidth[pieceName];
	
	new positionInPiece[POSITION]
	new positionInTable[POSITION]
	
	for(new i=0;i<pieceSquareWidth;i++)
	{
		positionInPiece[COL] = i		
		positionInTable[COL] = piecePosition[COL] + positionInPiece[COL]
		
		for(new j=0;j<pieceSquareWidth;j++)
		{
			positionInPiece[ROW] = (pieceSquareWidth - 1) - j;
			positionInTable[ROW] = piecePosition[ROW] - j
			
			if(0 <= positionInTable[COL] < TableCols)
			{
				if(pieceData[positionInPiece[ROW]][positionInPiece[COL]] && positionInTable[ROW] >= 0)
				{
					if(positionInTable[ROW] < TableRows)
					{
						if(PlayersTables[id][positionInTable[ROW]][positionInTable[COL]])
						{
							return false;
						}
					}
					else
					{
						return false;
					}
				}
			}
			else 
			{
				if(pieceData[positionInPiece[ROW]][positionInPiece[COL]])
				{
					return false;
				}
			}
		}
	}
	
	return true;
}
putPieceInTable(id)
{
	new pieceSquareWidth = PiecesSquareWidth[PlayersCurrentPieceName[id]];
	
	new positionInPiece[POSITION]
	new positionInTable[POSITION]
	
	for(new i=0;i<pieceSquareWidth;i++)
	{
		positionInPiece[COL] = i
		positionInTable[COL] = PlayersCurrentPiecePosition[id][COL] + i
		
		for(new j=0;j<pieceSquareWidth;j++)
		{
			positionInPiece[ROW] = (pieceSquareWidth - 1) - j;
			positionInTable[ROW] = PlayersCurrentPiecePosition[id][ROW] - j;
			
			if(positionInTable[ROW] < 0)
			{
				return false
			}
			else
			{
				if(PlayersCurrentPieceData[id][positionInPiece[ROW]][positionInPiece[COL]])
				{
					PlayersTables[id][positionInTable[ROW]][positionInTable[COL]] = true;
				}
			}			
		}
	}
	
	return true;
}

cleanRow(id)
{	
	for(new row=0;row<TableRows;row++)
	{
		new bool:fullRow = true;
		
		for(new col=0;col<TableCols;col++)
		{
			if(!PlayersTables[id][row][col])
			{
				fullRow = false;
				break;
			}
		}
		
		if(fullRow)
		{
			
			for(new col=0;col<TableCols;col++)
			{
				PlayersTables[id][row][col] = false;
			}
			
			return row;
		}
	}
	
	return -1;
}

handleGravityEffect(id,cleanedRow)
{
	for(new col=0;col<TableCols;col++)
	{
		new lowerCleanRow = cleanedRow
		
		for(new row= cleanedRow + 1; row < TableRows ; row++)
		{
			if(!PlayersTables[id][row][col])
			{
				lowerCleanRow = row;
			}
			else
			{
				break;
			}
		}
		
		for(new row = lowerCleanRow - 1; row >= 0; row--)
		{
			if(PlayersTables[id][row][col])
			{
				PlayersTables[id][row][col] = false;
				PlayersTables[id][lowerCleanRow--][col] = true;
			}
		}		
	}
}

public movePieceDownTask(params[])
{
	new id = params[0]
	new bool:createTask
	
	if(canMovePieceDown(id))
	{
		PlayersCurrentPiecePosition[id][ROW]++
		createTask = true;
	}
	else
	{
		if(putPieceInTable(id))
		{
			client_cmd(id,"spk %s",Sounds[FALL]);
			
			new row
			
			do
			{
				row = cleanRow(id)
				
				if(row != -1) 
				{
					client_cmd(id,"spk %s",Sounds[LINE]);
					
					handleGravityEffect(id,row)
				}				
			}
			while(row != -1);
				
			new PIECE_NAME:pieceName = PlayersNextPieceName[id]
			
			clonePiece(PlayersNextPieceData[id],PlayersCurrentPieceData[id],PlayersNextPiecePosition[id],PlayersCurrentPiecePosition[id],pieceName)
			
			PlayersCurrentPieceName[id] = pieceName;
			
			initPiecePosition(PlayersCurrentPiecePosition[id],pieceName);
			
			getRandomPiece(PlayersNextPieceData[id],PlayersNextPiecePosition[id],PlayersNextPieceName[id])
			
			createTask = true;
		}
		else
		{
			client_cmd(id,"spk %s",Sounds[GAMEOVER]);
			PlayersGameState[id] = GAME_OVER;
			
			playerQuitingGame(id);
		}
	}
	
	new menu,newmenu
	
	player_menu_info(id,menu,newmenu);
	
	if(newmenu == PlayersMenuInGame[id])
	{
		menuTetris(id);
		
		if(createTask)
			set_task(PlayersTaskDelay[id],"movePieceDownTask",PlayersTaskID[id],params,1,"a",1) 
	}
	else
	{
		playerQuitingGame(id);
	}
}

public menuTetrisInGamePre(id)
{
	menuTetrisInGame(id);
	
	if(!PlayersIsPlaying[id])
	{
		playerEnteringGame(id);
	}
	
}
public menuTetrisInGame(id)
{
	new menu = menu_create("","handleMenuTetrisInGame");
	
	PlayersMenuInGame[id] = menu;	
	
	menu_additem(menu,"Change Music","1");
	
	menu_addblank(menu,0)
	
	const rowStringLen = 3 * TableCols + 1;
	
	new currentPieceSquareWidth = PiecesSquareWidth[PlayersCurrentPieceName[id]];
	
	new currentPieceEndRow = PlayersCurrentPiecePosition[id][ROW]
	
	new currentPieceStartRow = currentPieceEndRow - currentPieceSquareWidth + 1
	
	new currentPieceStartCol = PlayersCurrentPiecePosition[id][COL]
	new currentPieceEndCol = currentPieceStartCol + currentPieceSquareWidth - 1;
	
	for(new row=0; row < currentPieceStartRow; row++)
	{
		PlayersTableCellActive[id] = false;
		
		new rowString[rowStringLen];
		format(rowString,2,cellCharColors[INACTIVE]);
		
		for(new col = 0;col < TableCols; col++)
		{
			new bool:active = PlayersTables[id][row][col] 
			
			if(active != PlayersTableCellActive[id])
			{
				PlayersTableCellActive[id] = active;
				format(rowString,rowStringLen-1,"%s%s",rowString,cellCharColors[CELL_COLOR:active]);
			}
			
			format(rowString,rowStringLen-1,"%s%s",rowString,cellChar);
		}
		
		menu_addtext(menu,rowString,0);
	}
	
	if(0 <= currentPieceEndRow)
	{
		if(currentPieceEndRow >= TableRows)
			currentPieceEndRow = TableRows - 1;
		
		for(new row = currentPieceStartRow; row <= currentPieceEndRow; row++)
		{
			if(row >= 0)
			{
				PlayersTableCellActive[id] = false;
				
				new rowString[rowStringLen];
				format(rowString,2,cellCharColors[INACTIVE]);
				
				for(new col=0;col<currentPieceStartCol;col++)
				{
					new bool:active = PlayersTables[id][row][col]
					
					if(active != PlayersTableCellActive[id])
					{
						PlayersTableCellActive[id] = active;
						format(rowString,rowStringLen-1,"%s%s",rowString,cellCharColors[CELL_COLOR:active]);
					}
					
					format(rowString,rowStringLen-1,"%s%s",rowString,cellChar);
				}
				
				new positionInPiece[POSITION]
				
				if(currentPieceEndCol >= TableCols)
					currentPieceEndCol = TableCols - 1;
				
				positionInPiece[ROW] = row - currentPieceStartRow;
				
				
				for(new col=currentPieceStartCol;col<=currentPieceEndCol;col++)
				{
					if(col >= 0)
					{
						positionInPiece[COL] = col - currentPieceStartCol;
						
						new bool:active = PlayersCurrentPieceData[id][positionInPiece[ROW]][positionInPiece[COL]] || PlayersTables[id][row][col]
						
						if(active != PlayersTableCellActive[id])
						{
							PlayersTableCellActive[id] = active;
							format(rowString,rowStringLen-1,"%s%s",rowString,cellCharColors[CELL_COLOR:active]);
						}
						
						format(rowString,rowStringLen-1,"%s%s",rowString,cellChar);
					}
				}
				
				for(new col=currentPieceEndCol+1;col< TableCols;col++)
				{
					new bool:active = PlayersTables[id][row][col]
					
					if(active != PlayersTableCellActive[id])
					{
						PlayersTableCellActive[id] = active;
						format(rowString,rowStringLen-1,"%s%s",rowString,cellCharColors[CELL_COLOR:active]);
					}
					
					format(rowString,rowStringLen-1,"%s%s",rowString,cellChar);
				}
				
				menu_addtext(menu,rowString,0);
			}
		}
	}
	
	for(new row=currentPieceEndRow+1; row < TableRows; row++)
	{
		PlayersTableCellActive[id] = false;
		
		new rowString[rowStringLen];
		format(rowString,2,cellCharColors[INACTIVE]);
		
		for(new col = 0;col < TableCols; col++)
		{
			new bool:active = PlayersTables[id][row][col]
			
			if(active != PlayersTableCellActive[id])
			{
				PlayersTableCellActive[id] = active;
				format(rowString,rowStringLen-1,"%s%s",rowString,cellCharColors[CELL_COLOR:active]);
			}
			
			format(rowString,rowStringLen-1,"%s%s",rowString,cellChar);
		}
		
		menu_addtext(menu,rowString,0);
	}
	
	menu_setprop(menu,MPROP_TITLE,MenuTextTitle);
	menu_setprop(menu,MPROP_EXITNAME,"exit");

	for(new i=2;i<=7;i++)
		menu_addtext(menu,"",1)
	
	
	menu_display(id,menu,0);
	
}

public handleMenuTetrisInGame(id,menu,item)
{
	if(item >= 0) 
	{
		new access, callback; 
		
		new actionString[2];		
		menu_item_getinfo(menu,item,access, actionString,1,_,_, callback);		
		new action = str_to_num(actionString);	
		
		switch(action)
		{
			case 0:
			{
				playerQuitingGame(id);
			}
			case 1:
			{
				client_cmd(id,"mp3 stop")
				client_cmd(id,"mp3 loop sound/%s",Musics[MUSIC:random(_:MUSIC)] );
				
				menuTetrisInGame(id)
			}
		}
	}
	
	menu_destroy(menu);
	
	return PLUGIN_HANDLED;
}	

public menuTetrisGameOver(id)
{
	client_cmd(id,"mp3 stop")
	
	new menu = menu_create("","handleMenuTetrisGameOver");
	
	menu_setprop(menu,MPROP_TITLE,MenuTextTitleGameOver);	
	menu_setprop(menu,MPROP_EXITNAME,"exit");
	
	menu_additem(menu,"Play again","1");
	
	menu_display(id,menu,0);
}

public handleMenuTetrisGameOver(id,menu,item)
{
	if(item >= 0) 
	{
		new access, callback; 
		
		new actionString[2];		
		menu_item_getinfo(menu,item,access, actionString,1,_,_, callback);		
		new action = str_to_num(actionString);	
		
		switch(action)
		{
			case 1:
			{
				PlayersGameState[id] = START
				menuTetris(id);
			}
		}
	}
	
	menu_destroy(menu);
	
	return PLUGIN_HANDLED;
}	
